summaryrefslogtreecommitdiff
path: root/PLUGINS
diff options
context:
space:
mode:
Diffstat (limited to 'PLUGINS')
-rw-r--r--PLUGINS/src/sky/HISTORY4
-rw-r--r--PLUGINS/src/sky/sky.c10
2 files changed, 9 insertions, 5 deletions
diff --git a/PLUGINS/src/sky/HISTORY b/PLUGINS/src/sky/HISTORY
index bdb440b..d41904e 100644
--- a/PLUGINS/src/sky/HISTORY
+++ b/PLUGINS/src/sky/HISTORY
@@ -8,3 +8,7 @@ VDR Plugin 'sky' Revision History
2002-12-13: Version 0.1.0
- Changed setting of CXX and CXXFLAGS variables in Makefile.
+
+2003-05-09: Version 0.1.1
+
+- Changed Start() to Initialize().
diff --git a/PLUGINS/src/sky/sky.c b/PLUGINS/src/sky/sky.c
index d6e10c9..ae59137 100644
--- a/PLUGINS/src/sky/sky.c
+++ b/PLUGINS/src/sky/sky.c
@@ -3,7 +3,7 @@
*
* See the README file for copyright information and how to reach the author.
*
- * $Id: sky.c 1.2 2002/12/13 15:01:57 kls Exp $
+ * $Id: sky.c 1.3 2003/05/09 15:27:16 kls Exp $
*/
#include <sys/socket.h>
@@ -14,7 +14,7 @@
#include <vdr/plugin.h>
#include <vdr/sources.h>
-static const char *VERSION = "0.1.0";
+static const char *VERSION = "0.1.1";
static const char *DESCRIPTION = "Sky Digibox interface";
// --- cDigiboxDevice --------------------------------------------------------
@@ -186,7 +186,7 @@ public:
virtual const char *Description(void) { return DESCRIPTION; }
virtual const char *CommandLineHelp(void);
virtual bool ProcessArgs(int argc, char *argv[]);
- virtual bool Start(void);
+ virtual bool Initialize(void);
virtual void Housekeeping(void);
virtual cMenuSetupPage *SetupMenu(void);
virtual bool SetupParse(const char *Name, const char *Value);
@@ -216,9 +216,9 @@ bool cPluginSky::ProcessArgs(int argc, char *argv[])
return true;
}
-bool cPluginSky::Start(void)
+bool cPluginSky::Initialize(void)
{
// Start any background activities the plugin shall perform.
new cDigiboxDevice;
return true;
}
@@ -216,9 +216,9 @@ bool cPluginSky::ProcessArgs(int argc, char *argv[])
{
- // Start any background activities the plugin shall perform.
+ // Initialize any background activities the plugin shall perform.
new cDigiboxDevice;
return true;